@@ -20,11 +20,11 @@ Finance::Bank::US::ShareBuilder - Check positions and transactions for US ShareB
 
 =head1 VERSION
 
-Version 0.01.3
+Version 0.01
 
 =cut
 
-our $VERSION = '0.01.3';
+our $VERSION = '0.01';
 
 =head1 SYNOPSIS
 
@@ -87,8 +87,8 @@ sub _login {
     $self->{ua}->default_header(Referer => "$base/authentication/signin.aspx");
     $response = $self->{ua}->post("$base/authentication/signin.aspx", [
         $self->_get_asp_junk,
-        'ctl00$ctl00$MainContent$MainContent$ucView$c$views$c$ucUsername$ctl00$txtUsername' => $self->{username},
-        'ctl00$ctl00$MainContent$MainContent$ucView$c$views$c$ucUsername$ctl00$btnSignIn' => 'ctl00$ctl00$MainContent$MainContent$ucView$c$views$c$ucUsername$ctl00$btnSignIn',
+        'ctl00$ctl00$MainContent$MainContent$ucView$c$views$c$ucUsername$ctl01$txtUsername' => $self->{username},
+        'ctl00$ctl00$MainContent$MainContent$ucView$c$views$c$ucUsername$ctl01$btnSignIn' => 'ctl00$ctl00$MainContent$MainContent$ucView$c$views$c$ucUsername$ctl01$btnSignIn',
     ]);
     $self->_update_asp_junk($response);
 
@@ -320,8 +320,6 @@ sub transactions {
     $to   = $to   ? DateTime->from_epoch(epoch => str2time($to))   : DateTime->today;
     $from = $from ? DateTime->from_epoch(epoch => str2time($from)) : $to->clone->add(months => -3);
 
-    $to = $to->add(days => 1);
-
     my $response = $self->{ua}->get("$base/Account/Records/History.aspx");
     $self->_update_asp_junk($response);
 
@@ -329,7 +327,7 @@ sub transactions {
 
     $self->{ua}->default_header(Referer => "$base/Account/Records/History.aspx");
     $response = $self->{ua}->post("$base/Account/Records/History.aspx", [
-        $c.'ddlAccountList' => $account,
+        $c.'ddlAccount' => $account,
         $c.'txtDateRange' => $from->mdy('/').' to '.$to->mdy('/'),
         $c.'ddlShow' => 'ALL',
         $c.'btnView' => 'ctl00$ctl00$MainContent$MainContent$uc',
@@ -381,16 +379,9 @@ sub transaction_list {
         @{$tree->{ofx}{seclistmsgsrsv1}{seclist}{stockinfo}};
 
     my $invlist = $tree->{ofx}{invstmtmsgsrsv1}{invstmttrnrs}{invstmtrs}{invtranlist};
-
-    my @buys = ref $invlist->{buystock} eq 'HASH' ? ($invlist->{buystock})
-        : ref $invlist->{buystock} eq 'ARRAY' ? @{$invlist->{buystock}}
-        : ();
-    my @sells = ref $invlist->{sellstock} eq 'HASH' ? ($invlist->{sellstock})
-        : ref $invlist->{sellstock} eq 'ARRAY' ? @{$invlist->{sellstock}}
-        : ();
-    my @reinvests = ref $invlist->{reinvest} eq 'HASH' ? ($invlist->{reinvest})
-        : ref $invlist->{reinvest} eq 'ARRAY' ? @{$invlist->{reinvest}}
-        : ();
+    my @buys  = @{$invlist->{buystock}}  if $invlist->{buystock};
+    my @sells = @{$invlist->{sellstock}} if $invlist->{sellstock};
+    my @reinvests = @{$invlist->{reinvest}} if $invlist->{reinvest};
 
     my @txns;
 
@@ -473,7 +464,7 @@ This version by Steven N. Severinghaus <sns-perl@severinghaus.org>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2012 Steven N. Severinghaus. All rights reserved. This
+Copyright (c) 2011 Steven N. Severinghaus. All rights reserved. This
 program is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
 
